

% The purpose of this tutorial is to  are several parameters that control what the stimuli look like
%  c1:   Contrast (range of gray levels) for first component
%  c2:   Contrast (range of gray levels) for second component
%  speedratio :  how fast is one component relative to the other
%  anglebetweencomponents:  The angle between the component's directions of motion

%  To make a movie with only one Plaid Component, set one of the contrasts to zero.

%%%%%%%%%%%
%  Here is an example of some stimulus parameters.  You will need to play with these in this assignment.
c1 = 0.6; 
c2 =1.0;
%anglebetweencomponents = 160;
anglebetweencomponents = 90;
speedratio = 1.2;

%  The analysis consists of the following steps
%  1)  Make a movie
%  2)  Analyze the movie in terms of derivatives
%  3)  Compute the likelihood of the velocity of these stimuli and prior
%  4)  Combine 

[imarray,movieframes] = MakePlaidMovie(c1,c2,anglebetweencomponents,speedratio);



% to show the movie, you can use:
movieview(movieframes);
% % if you want it to repeat twice, you can do
% movieview([movieframes movieframes])
% % or play backwards
% movieview(movieframes(end:-1:1))



% now compute the image derivatives
[Ix,Iy,It]=ComputeImageDerivs(imarray);

% to compute the velocity likelihood, first selection a spacetime region
pixellocation_ijt =[32 32 16]; % y=32, x=32, t=16
% and choose the size of the averaging window
window_sigma = 10; 

%  velocity range to compute the likelihood over
vellims = [-3 3];
%  if you want this chosen automatically, leave this blank.

% finally, decide how noisy our measurements are
Measure_sigma=1;

% compute the likelihood of vx,vy for a range of vx and vy
[p_Igivenv,Vx,Vy] = ComputeVelLikeli(Ix,Iy,It,Measure_sigma,pixellocation_ijt,window_sigma,vellims);
%
%compute the prior on vx, vy
%  choose Prior_sigma
Prior_sigma = 1;
P_v = ComputePrior(Vx,Vy,Prior_sigma);

Posterior_v = (p_Igivenv.*P_v)/sum(sum(p_Igivenv.*P_v));
[maxvx, maxvy] = maxPosteriori(Posterior_v, Vx, Vy)
% finally you can visualize the effects of the components and the
% probabilities
% for example, to view the area in the original movie and the likelihood
% for that region, call
ShowPdistandMovieFrames(imarray,pixellocation_ijt,window_sigma,p_Igivenv,Vx,Vy);
% for example, to view the area in the temporal derivative and the
% posterior
% for that region, call
ShowPdistandMovieFrames(imarray,pixellocation_ijt,window_sigma,Posterior_v,Vx,Vy);


%%%%%%%%%%%%%EXERCISE

% Based on Weiss,Simoncelli, and Adelson ?Motion Illusions as Optimal
% Percepts?.  We will simulate their theory on a simple stimulus.  I
% have written a series of utility files in Matlab for this purpose
% Make sure you have the following files: MakePlaidMovie.m, ComputePrior.m,
% ComputeVelLikeli.m, ComputeImageDerivs.m, ShowPdistandMovieFrames.m,
% and BayesianMotPerExample.m.    The function MakePlaidMovie will make
% an image sequence for a simple ?plaid? stimulus.  The other files will
% analyze and display the motion 

% Do the following steps for several
% different plaid stimuli
% 
% The assignment:
% a) Write a function to return maximum a posteriori velocity estimates.
% b)      Make a plot of ?perceived? velocity (maximum a posteriori estimates) for some
% image patch location against 1) the contrast of the second component,
% and 2) size of the averaging window.    Fix all other parameters at
% some reasonable values.
% c)        For some parameter combinations, the plaid components are
% not combined but appear to move separately.  Find a parameter set for
% which this is true for you and report it in your writeup.  Can you
% explain this phenomena using the theory outlined in the paper? Briefly
% explain why, or if not what can be done to fix the theory.
% d)       Can we make the likelihoods non-local?  Try to modify the code
% to achieve that.



